-----------------------------------------------
pirt.splinegrid - Representing data using grids
-----------------------------------------------

.. automodule:: pirt.splinegrid

----

.. autoclass:: pirt.GridInterface
    :members:

.. autoclass:: pirt.SplineGrid
    :members:

.. autoclass:: pirt.GridContainer
    :members:

.. autoclass:: pirt.FieldDescription
    :members:
